require "json"
require "faraday"
require "openssl"

require "feed_burner/version"
require "feed_burner/configurable"

module FeedBurner
  class << self
    include Configurable

    def feed(params, timeout = 10)
      validate_params!(params)
      response = Timeout::timeout(timeout) do
        ::Faraday.get(request_uri(params))
      end
      JSON.parse(response.body)
    end

    private

    def validate_params!(params)
      unless params[:trip_id].is_a?(String) && params[:username].is_a?(String)
        raise ArgumentError, "Invalid arguments specified: #{params}. Coordinator and Trip are required."
      end
    end

    def request_uri(params)
      uri = "http://localhost:3000/api/v1/feeds/#{params[:trip_id]}?"
      uri << "username=#{params[:username]}"
      uri << "&timestamp=#{Time.now.to_i}"
      uri << "&text_only=#{params[:text_only]}" if params[:text_only]

      signature = encrypted_token(uri)

      uri << "&signature=#{signature}"
    end

    def encrypted_token(uri)
      OpenSSL::HMAC.hexdigest(OpenSSL::Digest::Digest.new('sha1'), api_key.to_s, uri)
    end
  end
end
